==> syntool_metadata-1.0.168.tar.gz: syntool_metadata-1.0.168/syntool_metadata/validation.py <==
# -*- encoding: utf-8 -*-

"""
@author: <ziad.khoury.hanna@oceandatalab.com>

Copyright (C) 2014-2021 OceanDataLab

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import math
import datetime


def _py2_isfinite(x):
    """"""
    return (not math.isnan(x)) and (not math.isinf(x))


if hasattr(math, 'isfinite'):
    isfinite = math.isfinite
else:
    isfinite = _py2_isfinite


class ParameterValidationError(Exception):
    """"""
    pass


def require_params(params, required):
    missing = [x for x in required if 0 >= len(params.get(x, ''))]
    if 0 < len(missing):
        raise ParameterValidationError(
            '{} parameter(s) must be present in the request'.format(', '.join(missing))
        )


def get_float_param(params, param_name):
    try:
        value = float(params[param_name])
        if isfinite(value):
            return value
    except ValueError:
        pass
    raise ParameterValidationError(
        '{} parameter must a finite number'.format(param_name)
    )


def get_positive_int_param(params, param_name):
    try:
        value = int(params[param_name])
        if isfinite(value) and value >= 0:
            return value
    except ValueError:
        pass
    raise ParameterValidationError(
        '{} parameter must a positive finite number'.format(param_name)
    )


def get_date_param(params, param_name):
    try:
        ts = float(params[param_name])
        if isfinite(ts) and ts >= 0:
            return datetime.datetime.utcfromtimestamp(ts)
    except ValueError:
        pass
    raise ParameterValidationError(
        '{} parameter must a positive finite number'.format(param_name)
    )

==> syntool_metadata-1.0.189.tar.gz: syntool_metadata-1.0.189/syntool_metadata/validation.py <==
# -*- encoding: utf-8 -*-

"""
@author: <ziad.khoury.hanna@oceandatalab.com>

Copyright (C) 2014-2024 OceanDataLab

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import math
import datetime
from syntool_metadata.pattern import (
    parse as _parse_pattern,
    simplify_ast as simplify_pattern_ast
)


def _py2_isfinite(x):
    """"""
    return (not math.isnan(x)) and (not math.isinf(x))


if hasattr(math, 'isfinite'):
    isfinite = math.isfinite
else:
    isfinite = _py2_isfinite


class ParameterValidationError(Exception):
    """"""
    pass


def require_params(params, required):
    missing = [x for x in required if 0 >= len(params.get(x, ''))]
    if 0 < len(missing):
        msg = ', '.join(missing)
        raise ParameterValidationError(
            '{} parameter(s) must be present in the request'.format(msg)
        )


def get_float_param(params, param_name):
    try:
        value = float(params[param_name])
        if isfinite(value):
            return value
    except ValueError:
        pass
    raise ParameterValidationError(
        '{} parameter must a finite number'.format(param_name)
    )


def get_positive_int_param(params, param_name):
    try:
        value = int(params[param_name])
        if isfinite(value) and value >= 0:
            return value
    except ValueError:
        pass
    raise ParameterValidationError(
        '{} parameter must a positive finite number'.format(param_name)
    )


def get_date_param(params, param_name):
    try:
        ts = float(params[param_name])
        if isfinite(ts) and ts >= 0:
            return datetime.datetime.utcfromtimestamp(ts)
    except ValueError:
        pass
    raise ParameterValidationError(
        '{} parameter must a positive finite number'.format(param_name)
    )


def get_optional_patterns_param(params, param_name):
    patterns = params.get(param_name, None)
    if not patterns:
        return None

    patterns = patterns.split(',')
    for i, p in enumerate(patterns):
        # complex pattern
        reason = None
        try:
            patterns[i] = simplify_pattern_ast(_parse_pattern(p))
        except ValueError as e:
            reason = e.args[0]
        if reason is not None:
            raise ParameterValidationError(
                'Pattern at index {} of {} parameter is invalid: {}'
                .format(i, param_name, reason)
            )

    return patterns
